@@ -17,8 +17,8 @@ package PostScript::Report::Builder;
 # ABSTRACT: Build a PostScript::Report object
 #---------------------------------------------------------------------
 
-our $VERSION = '0.10';
-# This file is part of PostScript-Report 0.10 (April 4, 2012)
+our $VERSION = '0.11';
+# This file is part of PostScript-Report 0.11 (April 27, 2013)
 
 use 5.008;
 use Moose;
@@ -216,9 +216,9 @@ sub create_fonts
 
   my %font;
 
-  while (my ($name, $desc) = each %$desc) {
-    $desc =~ /^(.+)-(\d+(?:\.\d+)?)/
-        or die "Invalid font description $desc for $name";
+  for my $name (sort keys %$desc) {
+    $desc->{$name} =~ /^(.+)-(\d+(?:\.\d+)?)/
+        or die "Invalid font description $desc->{$name} for $name";
 
     $font{$name} = $rpt->get_font($1, $2);
   }
@@ -430,9 +430,9 @@ PostScript::Report::Builder - Build a PostScript::Report object
 
 =head1 VERSION
 
-This document describes version 0.10 of
-PostScript::Report::Builder, released April 4, 2012
-as part of PostScript-Report version 0.10.
+This document describes version 0.11 of
+PostScript::Report::Builder, released April 27, 2013
+as part of PostScript-Report version 0.11.
 
 =head1 SYNOPSIS
 
@@ -702,7 +702,7 @@ It wouldn't have happened without them.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Christopher J. Madsen.
+This software is copyright (c) 2013 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
